@@ -3,7 +3,7 @@ function add_arrows_defs(chart) {
     // <defs>
     var defs = chart.svg().append("defs");
     // arrow head markers
-    chart.scales().color.range().forEach(function(d) {
+    chart.scales().color.range().forEach(d => {
         defs.append("marker")
 	    .attr("id", "arrow-head-" + chart.settings().html_id + "-" + d)
 	    .attr("markerWidth", "10")
@@ -48,7 +48,7 @@ function arrows_update(chart) {
         .transition().duration(1000)
         .call(arrow_formatting, chart)
         .style("opacity", "1");
-    
+
     arrows.exit()
         .transition().duration(1000)
         .style("opacity", "0")
@@ -59,25 +59,25 @@ function arrows_update(chart) {
 // Arrow drawing function
 function draw_arrow(selection, chart) {
     selection
-        .attr("x1", function(d) { return chart.scales().x(0); })
-        .attr("y1", function(d) { return chart.scales().y(0); })
-        .attr("x2", function(d) { return chart.scales().x(d.x); })
-        .attr("y2", function(d) { return chart.scales().y(d.y); });
+        .attr("x1", d => chart.scales().x(0))
+        .attr("y1", d => chart.scales().y(0))
+        .attr("x2", d => chart.scales().x(d.x))
+        .attr("y2", d => chart.scales().y(d.y));
 }
 
 // Initial arrow attributes
 function arrow_init(selection, chart) {
     // tooltips when hovering points
     if (chart.settings().has_tooltips) {
-        var tooltip = d3v5.select(".scatterD3-tooltip");
-        selection.on("mouseover", function(d, i){
+        var tooltip = d3v7.select(".scatterD3-tooltip");
+        selection.on("mouseover", (event, d, i) => {
             tooltip.style("visibility", "visible")
                 .html(tooltip_content(d, chart));
         });
-        selection.on("mousemove", function(){
-            tooltip.style("top", (d3v5.event.pageY+15)+"px").style("left",(d3v5.event.pageX+15)+"px");
+        selection.on("mousemove", event => {
+            tooltip.style("top", (event.pageY+15)+"px").style("left",(d3v7.event.pageX+15)+"px");
         });
-        selection.on("mouseout", function(){
+        selection.on("mouseout", event => {
             tooltip.style("visibility", "hidden");
         });
     }
@@ -89,9 +89,9 @@ function arrow_formatting(selection, chart) {
         .call(draw_arrow, chart)
         .style("stroke-width", "1px")
     // stroke color
-        .style("stroke", function(d) { return chart.scales().color(d.col_var); })
-        .attr("marker-end", function(d) { return "url(#arrow-head-" + chart.settings().html_id + "-" + chart.scales().color(d.col_var) + ")"; })
-        .attr("class", function(d,i) { return "arrow color color-c" + css_clean(d.col_var); })
+        .style("stroke", d => chart.scales().color(d.col_var))
+        .attr("marker-end", d => "url(#arrow-head-" + chart.settings().html_id + "-" + chart.scales().color(d.col_var) + ")")
+        .attr("class", d => "arrow color color-c" + css_clean(d.col_var))
         .style("opacity", function(d) {
 	    return d.opacity_var !== undefined ? chart.scales().opacity(d.opacity_var) : chart.settings().point_opacity;
 	});
